#
# spec file for package mmc-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mmc-utils
Version:        0.1+git.20240307
Release:        1.2
Summary:        Tools for MMC/SD devices
License:        GPL-2.0-only
URL:            https://git.kernel.org/cgit/linux/kernel/git/cjb/mmc-utils.git/
Source0:        %{name}-%{version}.tar.gz
Source1:        https://www.gnu.org/licenses/gpl-2.0.txt

%description
Userspace tools for controlling and querying MMC/SD storage devices

%prep
%autosetup
cp %{SOURCE1} LICENSE.GPL-2.0

%build
%make_build CFLAGS="%{optflags}" CHECKFLAGS="-Wall -Wuninitialized -Wundef"

%install
%make_install prefix=%{_prefix}
install -D -p -m 0644 man/mmc.1 \
  %{buildroot}%{_mandir}/man1/mmc.1

%files
%license LICENSE.GPL-2.0
%{_bindir}/mmc
%{_mandir}/man1/mmc.1%{?ext_man}

%changelog
* Thu Mar 14 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20240307:
  * mmc-utils: mmc_cmds: fix type-punned warning on &ext_csd[] casting
  * mmc-utils: lsmmc: Fix emmc capacity calculation
  * mmc-utils: lsmmc: Disintegrade print_mmc_csd
  * mmc-utils: lsmmc: Simplify interface processing functions
  * mmc-utils: lsmmc: Simplify prinitng manufacturer name
  * mmc-utils: lsmmc: Reuse do_read_reg
  * mmc-utils: fix potential overflow
  * mmc-utils: ffu: Add optional chunk-size argument
  * mmc-utils: ffu: Allow ffu of large images
  * mmc-utils: ffu: Add ffu multi-command set handler
  * mmc-utils: ffu: Simplify ext_csd bytes parsing
  * mmc-utils: Add arg argument to set_single_cmd
  * mmc-utils: Add fill_switch_cmd handler
  * mmc-utils: Assert MMC_IOC_MULTI_CMD in compile time
  * mmc-utils: support overriding CFLAGS without setting -DVERSION
  * mmc-utils: do not hide CID manufacturer information
  * mmc-utils: fix printing OID for mmc in non-verbose mode
  * mmc-utils: add SanDisk to manufacturer database
  * mmc-utils: Change version string to git hash
* Fri Mar 24 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20230209:
  * mmc-utils: Add basic erase error check
  * mmc-utils: Add a command to write extcsd registers
  * mmc-utils: Implement alternative boot operation
  * mmc-utils: Add CMD0 softreset and preidle command
  * mmc-utils: Allow for custom sanitize timeout
  * mmc-utils: Refactor switch to allow custom timeout
  * mmc-utils: Fix a typo for ATP mid
  * mmc-utils: Fix ffu in case of unsupported MODE_OPERATION_CODES
  * mmc-utils: fix warning on uninitialized 'cnt'
  * mmc-utils: correct and clean up the file handling
  * mmc-utils: Fix 4k sector size block count in FFU
  * mmc-utils: Add General command CMD56 read support
  * mmc-utils: Fix build error MMC_BLOCK_MAJOR undeclared
  * Enhancement to do_status_get() function for detailed Response info
* Thu Feb 17 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20220208:
  * mmc-utils: Display STROBE_SUPPORT when printing EXT_CSD
  * mmc-utils: Remove unused MMC_BLOCK_MAJOR
  * mmc-utils: manpage: Document -c option for partitioning commands
  * mmc_cmds: Display BARRIER_CTRL Status when printing EXT_CSD
  * add README
* Tue Jan  4 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20211220:
  * mmc_cmds: add HS400 data rates
  * mmc-utils: Use printf() to extract and print fw version
  * mmc-utils: Add note for CMDQ_MODE_EN runtime value
* Tue Oct 19 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20210930:
  * mmc-utils: One further optimization of trimming routine
* Tue Sep 14 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20210824:
  * mmc-utils: Fix for Firmware Version string printing
* Thu Jun 24 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20210511:
  * mmc-utils: Add eMMC erase command support
* Wed Apr 28 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20210330:
  * Various fixes
  * Add various SD/eMMC vendors to table
  * Fix parsing of Product Revision and Serial Number
  * mmc_cmds.c: fix build with gcc 4.9
  * mmc-utils: Add AUTO_EN support in the BKOPS_EN
  * mmc-utils: Expand 'writeprotect boot'
  * mmc-utils: Fix scaling of cache size
  * rpmb: Zero-init MMC_IOC_MULTI_CMD structures
  * mmc-utils: let FFU mode use CMD23 and CMD25
* Mon Feb  3 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20191004:
  * Add eMMC vendor Micron to table
  * Optimize to_binstr() function
  * Fix parsing of character in to_binstr()
  * Cleanup memory in error case
  * Check calloc's return value before using the pointer
  * mmc-utils: feature spec 5.0+, add secure removal type fields to Extended CSD
  * mmc-utils: use MMC_IOC_MULTI_CMD for RPMB access
  * use proper type for RPMB blocks_cnt
  * fix GCC7 build by refactoring trimming routines
  * fix ENH_START_ADDR overflow
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20190808:
  * mmc-utils: feature spec 5.0+, add secure removal type fields to Extended CSD
  * mmc-utils: use MMC_IOC_MULTI_CMD for RPMB access
* Fri Dec 14 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.1+git.20181208:
  * use proper type for RPMB blocks_cnt
  * fix GCC7 build by refactoring trimming routines
* Mon Jun 18 2018 mpluskal@suse.com
- Update to version 0.1+git.20180327:
  * fix ENH_START_ADDR overflow
- Dont build with -Werror
* Thu Mar  8 2018 mpluskal@suse.com
- Update to version 0.1+git.20180216:
  * mmc-utils: manpage: fix arguments for TH macro
  * mmc-utils: remove unused #includes
  * mmc-utils: move offsetof from mmc.h to only user
  * mmc-utils: expand .gitignore
  * mmc-utils: make use of dependency information generated by gcc
  * mmc-utils: drop unused header
  * mmc-utils: drop macro CHECK
- Drop do_not_use_asm_generic.patch
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 0.1+git.20170320:
  * mmc-utils: feature spec 5.0+, device life time estimation for MLC and pSLC mode
  * mmc-utils: feature spec 5.0+, Pre EOL information
  * mmc-utils: Check for ext_csd_rev only once
* Fri Sep  9 2016 mpluskal@suse.com
- Update to version 0.1+git.20160901:
  * Fix reported offset for enhanced user area start address
  * Register being set is other than mentioned in printed message.
  * Add -c option for partitioning commands
  * Add help texts for -c option
  * Fix return value check from set_partitioning_setting_completed()
  * Add missing -c for write_reliability
* Wed Jun 29 2016 mpluskal@suse.com
- Update to version 0.1+git.20160623:
  * mmc-utils: Add ability to configure write protect on an eMMC device
  * mmc-utils: Add Command Queue fields to Extended CSD
* Thu May 12 2016 mpluskal@suse.com
- Update to version 0.1+git.20160511:
  * mmc-utils: Add disable partition boot to 'mmc bootpart enable'
* Wed Mar  9 2016 mpluskal@suse.com
- Update to version 0.1~git.20160308:
  + Fit usage to 80 cols
  + fix building errors on Android
  + mmc-utils: add check for max enhanced user area
  + mmc-utils: add support to create gp partition
  + mmc-utils: Add command to set the boot bus conditions
  + mmc-utils: add ability to enable/disable optional eMMC cache
  + mmc_utils: gp create: only allow partition [1-4] to be selected
  + mmc_utils: doc: add man-page
  + mmc-utils: Merge the lsmmc tool into mmc-utils
  + mmc_utils: add ffu support
* Tue Mar  1 2016 mpluskal@suse.com
- Update to 0.1~20160223
- Drop old versioning which was based only on date
* Wed Feb 17 2016 normand@linux.vnet.ibm.com
- new do_not_use_asm_generic.patch to avoid PowerPC build error
* Sat Dec  5 2015 mpluskal@suse.com
- Update to 20151118
- Install man page
- Build with correct optflags
* Thu Dec 25 2014 mpluskal@suse.com
- Initial packaging of current git snapshot (20140812)
